@@ -178,12 +178,6 @@ namespace anyks {
 			// Объект log файла
 			mutable const char * logfile = nullptr;
 		private:
-			/**
-			 * event Метод проверки на спец-слово
-			 * @param idw идентификатор слова для проверки
-			 * @return    результат проверки
-			 */
-			const bool event(const size_t idw) const noexcept;
 			/**
 			 * isOption Метод проверки наличия опции
 			 * @param option опция для проверки
@@ -280,6 +274,41 @@ namespace anyks {
 			 */
 			const ppl_t pplByFiles(const string & path, function <void (const u_short)> status = nullptr, const string & ext = "txt") const noexcept;
 		public:
+			/**
+			 * check Метод проверки существования последовательности, с указанным шагом
+			 * @param text текст для проверки существования
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const bool check(const string & text, const u_short step) const noexcept;
+			/**
+			 * check Метод проверки существования последовательности, с указанным шагом
+			 * @param text текст для проверки существования
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const bool check(const wstring & text, const u_short step) const noexcept;
+			/**
+			 * check Метод проверки существования последовательности, с указанным шагом
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const bool check(const vector <string> & seq, const u_short step) const noexcept;
+			/**
+			 * check Метод проверки существования последовательности, с указанным шагом
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const bool check(const vector <wstring> & seq, const u_short step) const noexcept;
+			/**
+			 * check Метод проверки существования последовательности, с указанным шагом
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			virtual const bool check(const vector <size_t> & seq, const u_short step) const noexcept;
 			/**
 			 * check Метод проверки существования последовательности
 			 * @param text     текст для проверки существования
@@ -315,6 +344,42 @@ namespace anyks {
 			 * @return         результат проверки
 			 */
 			virtual const pair <bool, size_t> check(const vector <size_t> & seq, const bool accurate = false) const noexcept;
+		public:
+			/**
+			 * exist Метод проверки существования последовательности
+			 * @param text текст для проверки существования
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const pair <bool, size_t> exist(const string & text, const u_short step) const noexcept;
+			/**
+			 * exist Метод проверки существования последовательности
+			 * @param text текст для проверки существования
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const pair <bool, size_t> exist(const wstring & text, const u_short step) const noexcept;
+			/**
+			 * exist Метод проверки существования последовательности
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const pair <bool, size_t> exist(const vector <string> & seq, const u_short step) const noexcept;
+			/**
+			 * exist Метод проверки существования последовательности
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const pair <bool, size_t> exist(const vector <wstring> & seq, const u_short step) const noexcept;
+			/**
+			 * exist Метод проверки существования последовательности
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			virtual const pair <bool, size_t> exist(const vector <size_t> & seq, const u_short step) const noexcept;
 		public:
 			/**
 			 * fixUppers Метод исправления регистров в тексте
@@ -338,7 +403,7 @@ namespace anyks {
 			 * getBin Метод извлечения данных arpa в бинарном виде
 			 * @param callback функция обратного вызова
 			 */
-			virtual void getBin(function <void (const vector <char> &, const u_short)> callback) const noexcept;
+			virtual void getBin(function <void (const vector <char> &, const size_t, const u_short)> callback) const noexcept;
 		public:
 			/**
 			 * clear Метод очистки всех данных
@@ -602,6 +667,16 @@ namespace anyks {
 			 * @param ext      расширение файлов в каталоге (если адрес передан каталога)
 			 */
 			void countsByFiles(const string & path, const string & filename, const u_short ngrams = 0, function <void (const string &, const u_short)> status = nullptr, const string & ext = "txt") const noexcept;
+		public:
+			/**
+			 * checkByFiles Метод проверки существования последовательности в текстовом файле
+			 * @param path     адрес каталога или файла для обработки
+			 * @param filename адрес файла для записи результата
+			 * @param step     шаг размера N-граммы для перебора текста
+			 * @param status   функция вывода статуса
+			 * @param ext      расширение файлов в каталоге (если адрес передан каталога)
+			 */
+			void checkByFiles(const string & path, const string & filename, const u_short step, function <void (const string &, const u_short)> status = nullptr, const string & ext = "txt") const noexcept;
 			/**
 			 * checkByFiles Метод проверки существования последовательности в текстовом файле
 			 * @param path     адрес каталога или файла для обработки
@@ -832,6 +907,20 @@ namespace anyks {
 			 * @return     результат расчёта
 			 */
 			virtual const ppl_t perplexity(const vector <size_t> & seq) const noexcept;
+			/**
+			 * check Метод проверки существования последовательности, с указанным шагом
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			virtual const bool check(const vector <size_t> & seq, const u_short step) const noexcept;
+			/**
+			 * exist Метод проверки существования последовательности
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			virtual const pair <bool, size_t> exist(const vector <size_t> & seq, const u_short step) const noexcept;
 			/**
 			 * check Метод проверки существования последовательности
 			 * @param seq      список слов последовательности
@@ -849,7 +938,7 @@ namespace anyks {
 			 * getBin Метод извлечения данных arpa в бинарном виде
 			 * @param callback функция обратного вызова
 			 */
-			virtual void getBin(function <void (const vector <char> &, const u_short)> callback) const noexcept;
+			virtual void getBin(function <void (const vector <char> &, const size_t, const u_short)> callback) const noexcept;
 		public:
 			/**
 			 * sentences Метод генерации предложений
@@ -980,6 +1069,20 @@ namespace anyks {
 			 * @return     результат расчёта
 			 */
 			const ppl_t perplexity(const vector <size_t> & seq) const noexcept;
+			/**
+			 * check Метод проверки существования последовательности, с указанным шагом
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const bool check(const vector <size_t> & seq, const u_short step) const noexcept;
+			/**
+			 * exist Метод проверки существования последовательности
+			 * @param seq  список слов последовательности
+			 * @param step размер шага проверки последовательности
+			 * @return     результат проверки
+			 */
+			const pair <bool, size_t> exist(const vector <size_t> & seq, const u_short step) const noexcept;
 			/**
 			 * check Метод проверки существования последовательности
 			 * @param seq      список слов последовательности
@@ -1002,7 +1105,7 @@ namespace anyks {
 			 * getBin Метод извлечения данных arpa в бинарном виде
 			 * @param callback функция обратного вызова
 			 */
-			void getBin(function <void (const vector <char> &, const u_short)> callback) const noexcept;
+			void getBin(function <void (const vector <char> &, const size_t, const u_short)> callback) const noexcept;
 		public:
 			/**
 			 * sentences Метод генерации предложений
