@@ -23,6 +23,13 @@
 #include <cstring>
 #include <algorithm>
 #include <sys/types.h>
+// Если используется BOOST
+#ifdef USE_BOOST_CONVERT
+	#include <boost/locale/encoding_utf.hpp>
+// Если нужно использовать стандартную библиотеку
+#else
+	#include <codecvt>
+#endif
 /**
  * Наши модули
  */
@@ -392,12 +399,30 @@ namespace anyks {
 			 * @return       результат проверки
 			 */
 			const bool isRoute(const wchar_t letter) const noexcept;
+			/**
+			 * isNumber Метод проверки является ли слово числом
+			 * @param  word слово для проверки
+			 * @return      результат проверки
+			 */
+			const bool isNumber(const string & word) const noexcept;
 			/**
 			 * isNumber Метод проверки является ли слово числом
 			 * @param  word слово для проверки
 			 * @return      результат проверки
 			 */
 			const bool isNumber(const wstring & word) const noexcept;
+			/**
+			 * isLetter Метод проверки на разрешённую букву
+			 * @param  letter буква для проверки
+			 * @return        результат проверки
+			 */
+			const bool isLetter(const wchar_t letter) const noexcept;
+			/**
+			 * isDecimal Метод проверки является ли слово дробным числом
+			 * @param  word слово для проверки
+			 * @return      результат проверки
+			 */
+			const bool isDecimal(const string & word) const noexcept;
 			/**
 			 * isDecimal Метод проверки является ли слово дробным числом
 			 * @param  word слово для проверки
